@@ -35,9 +35,10 @@ static void gs_prefs_init       (GSPrefs      *prefs);
 static void gs_prefs_finalize   (GObject      *object);
 
 #define KEY_DIR            "/apps/gnome-screensaver"
+#define KEY_IDLE_ACTIVATION_ENABLED         KEY_DIR "/idle_activation_enabled"
 #define KEY_LOCK_ENABLED   KEY_DIR "/lock_enabled"
 #define KEY_MODE           KEY_DIR "/mode"
-#define KEY_ACTIVATE_DELAY KEY_DIR "/activate_delay"
+#define KEY_ACTIVATE_DELAY KEY_DIR "/idle_delay"
 #define KEY_LOCK_DELAY     KEY_DIR "/lock_delay"
 #define KEY_CYCLE_DELAY    KEY_DIR "/cycle_delay"
 #define KEY_DPMS_ENABLED   KEY_DIR "/dpms_enabled"
@@ -70,14 +71,13 @@ static GConfEnumStringPair mode_enum_map [] = {
        { GS_MODE_BLANK_ONLY,       "blank-only" },
        { GS_MODE_RANDOM,           "random"     },
        { GS_MODE_SINGLE,           "single"     },
-       { GS_MODE_DONT_BLANK,       "disabled"   },
        { 0, NULL }
 };
 
 static GObjectClass *parent_class = NULL;
 static guint         signals [LAST_SIGNAL] = { 0, };
 
-G_DEFINE_TYPE (GSPrefs, gs_prefs, G_TYPE_OBJECT);
+G_DEFINE_TYPE (GSPrefs, gs_prefs, G_TYPE_OBJECT)
 
 static void
 gs_prefs_set_property (GObject            *object,
@@ -85,10 +85,6 @@ gs_prefs_set_property (GObject            *object,
                        const GValue       *value,
                        GParamSpec         *pspec)
 {
-        GSPrefs *self;
-
-        self = GS_PREFS (object);
-
         switch (prop_id) {
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -102,10 +98,6 @@ gs_prefs_get_property (GObject            *object,
                        GValue             *value,
                        GParamSpec         *pspec)
 {
-        GSPrefs *self;
-
-        self = GS_PREFS (object);
-
         switch (prop_id) {
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -141,82 +133,330 @@ gs_prefs_class_init (GSPrefsClass *klass)
 }
 
 static void
-gs_prefs_load_from_gconf (GSPrefs *prefs)
+_gs_prefs_set_timeout (GSPrefs *prefs,
+                       int      value)
 {
-        glong value;
-        char *string;
-        int   mode;
-
-        prefs->lock_enabled = gconf_client_get_bool (prefs->priv->gconf_client, KEY_LOCK_ENABLED, NULL);
-
-        value = gconf_client_get_int (prefs->priv->gconf_client, KEY_ACTIVATE_DELAY, NULL);
         if (value < 1)
                 value = 10;
-        prefs->timeout = value * 60000;
 
-        value = gconf_client_get_int (prefs->priv->gconf_client, KEY_LOCK_DELAY, NULL);
+        /* pick a reasonable large number for the
+           upper bound */
+        if (value > 480)
+                value = 480;
+
+        prefs->timeout = value * 60000;
+}
+
+static void
+_gs_prefs_set_lock_timeout (GSPrefs *prefs,
+                            int      value)
+{
         if (value < 0)
                 value = 0;
+
+        /* pick a reasonable large number for the
+           upper bound */
+        if (value > 480)
+                value = 480;
+
         prefs->lock_timeout = value * 60000;
+}
 
-        value = gconf_client_get_int (prefs->priv->gconf_client, KEY_CYCLE_DELAY, NULL);
+static void
+_gs_prefs_set_cycle_timeout (GSPrefs *prefs,
+                             int      value)
+{
         if (value < 1)
-                value = 60;
-        prefs->cycle = value * 60000;
+                value = 1;
 
-        string = gconf_client_get_string (prefs->priv->gconf_client, KEY_MODE, NULL);
-	if (string && gconf_string_to_enum (mode_enum_map, string, &mode))
+        /* pick a reasonable large number for the
+           upper bound */
+        if (value > 480)
+                value = 480;
+
+        prefs->cycle = value * 60000;
+}
+
+static void
+_gs_prefs_set_mode (GSPrefs    *prefs,
+                    const char *value)
+{
+        int mode;
+
+	if (value && gconf_string_to_enum (mode_enum_map, value, &mode))
                 prefs->mode = mode;
         else
                 prefs->mode = GS_MODE_BLANK_ONLY;
-        g_free (string);
+}
 
+static void
+_gs_prefs_set_themes (GSPrefs *prefs,
+                      GSList  *list)
+{
         if (prefs->themes) {
                 g_slist_foreach (prefs->themes, (GFunc)g_free, NULL);
                 g_slist_free (prefs->themes);
         }
 
-        prefs->themes = gconf_client_get_list (prefs->priv->gconf_client,
-                                               KEY_THEMES, GCONF_VALUE_STRING, NULL);
+        /* take ownership of the list */
+        prefs->themes = list;
+}
 
-        /* DPMS options */
+static void
+_gs_prefs_set_idle_activation_enabled (GSPrefs *prefs,
+                                       gboolean value)
+{
+        prefs->idle_activation_enabled = value;
+}
 
-        prefs->dpms_enabled = gconf_client_get_bool (prefs->priv->gconf_client, KEY_DPMS_ENABLED, NULL);
-        value = gconf_client_get_int (prefs->priv->gconf_client, KEY_DPMS_STANDBY, NULL);
+static void
+_gs_prefs_set_lock_enabled (GSPrefs *prefs,
+                            gboolean value)
+{
+        prefs->lock_enabled = value;
+}
+
+static void
+_gs_prefs_set_dpms_enabled (GSPrefs *prefs,
+                            gboolean value)
+{
+        prefs->dpms_enabled = value;
+}
+
+static void
+_gs_prefs_set_dpms_standby_timeout (GSPrefs *prefs,
+                                    int      value)
+{
         if (value < 0)
                 value = 0;
+
+        /* pick a reasonable large number for the
+           upper bound */
+        if (value > 480)
+                value = 480;
+
+        /* FIXME: should make sure standby < suspend < off */
+
         prefs->dpms_standby = value * 60000;
-        value = gconf_client_get_int (prefs->priv->gconf_client, KEY_DPMS_SUSPEND, NULL);
+}
+
+static void
+_gs_prefs_set_dpms_suspend_timeout (GSPrefs *prefs,
+                                    int      value)
+{
         if (value < 0)
                 value = 0;
+
+        /* pick a reasonable large number for the
+           upper bound */
+        if (value > 480)
+                value = 480;
+
+        /* FIXME: should make sure standby < suspend < off */
+
         prefs->dpms_suspend = value * 60000;
-        value = gconf_client_get_int (prefs->priv->gconf_client, KEY_DPMS_OFF, NULL);
+}
+
+static void
+_gs_prefs_set_dpms_off_timeout (GSPrefs *prefs,
+                                int      value)
+{
         if (value < 0)
                 value = 0;
+
+        /* pick a reasonable large number for the
+           upper bound */
+        if (value > 480)
+                value = 480;
+
+        /* FIXME: should make sure standby < suspend < off */
+
         prefs->dpms_off = value * 60000;
+}
 
+static void
+_gs_prefs_set_logout_enabled (GSPrefs *prefs,
+                              gboolean value)
+{
+        prefs->logout_enabled = value;
+}
 
-        /* Logout options */
-
-        prefs->logout_enabled = gconf_client_get_bool (prefs->priv->gconf_client, KEY_LOGOUT_ENABLED, NULL);
-
-        string = gconf_client_get_string (prefs->priv->gconf_client, KEY_LOGOUT_COMMAND, NULL);
+static void
+_gs_prefs_set_logout_command (GSPrefs    *prefs,
+                              const char *value)
+{
         g_free (prefs->logout_command);
-        if (string) {
-                prefs->logout_command = g_strdup (string);
+        prefs->logout_command = NULL;
+
+       if (value) {
+               /* FIXME: check command */
+
+               prefs->logout_command = g_strdup (value);
+        }
+}
+
+static void
+_gs_prefs_set_logout_timeout (GSPrefs *prefs,
+                              int      value)
+{
+        if (value < 0)
+                value = 0;
+
+        /* pick a reasonable large number for the
+           upper bound */
+        if (value > 480)
+                value = 480;
+
+        prefs->logout_timeout = value * 60000;
+}
+
+static void
+_gs_prefs_set_user_switch_enabled (GSPrefs *prefs,
+                                   gboolean value)
+{
+        prefs->user_switch_enabled = value;
+}
+
+static void
+key_error_and_free (const char *key,
+                    GError     *error)
+{
+        g_warning ("Error retrieving configuration key '%s': %s", key, error->message);
+        g_error_free (error);
+        error = NULL;
+}
+
+static void
+gs_prefs_load_from_gconf (GSPrefs *prefs)
+{
+        glong    value;
+        gboolean bvalue;
+        char    *string;
+        GSList  *list;
+        GError  *error;
+
+        error = NULL;
+
+        bvalue = gconf_client_get_bool (prefs->priv->gconf_client, KEY_IDLE_ACTIVATION_ENABLED, &error);
+        if (! error) {
+                _gs_prefs_set_idle_activation_enabled (prefs, bvalue);
         } else {
-                prefs->logout_command = NULL;
+                key_error_and_free (KEY_IDLE_ACTIVATION_ENABLED, error);
+        }
+
+        bvalue = gconf_client_get_bool (prefs->priv->gconf_client, KEY_LOCK_ENABLED, &error);
+        if (! error) {
+                _gs_prefs_set_lock_enabled (prefs, bvalue);
+        } else {
+                key_error_and_free (KEY_LOCK_ENABLED, error);
+        }
+
+        value = gconf_client_get_int (prefs->priv->gconf_client, KEY_ACTIVATE_DELAY, &error);
+        if (! error) {
+                _gs_prefs_set_timeout (prefs, value);
+        } else {
+                key_error_and_free (KEY_ACTIVATE_DELAY, error);
+        }
+
+        value = gconf_client_get_int (prefs->priv->gconf_client, KEY_LOCK_DELAY, &error);
+        if (! error) {
+                _gs_prefs_set_lock_timeout (prefs, value);
+        } else {
+                key_error_and_free (KEY_LOCK_DELAY, error);
+        }
+
+        value = gconf_client_get_int (prefs->priv->gconf_client, KEY_CYCLE_DELAY, &error);
+        if (! error) {
+                _gs_prefs_set_cycle_timeout (prefs, value);
+        } else {
+                key_error_and_free (KEY_CYCLE_DELAY, error);
+        }
+
+        string = gconf_client_get_string (prefs->priv->gconf_client, KEY_MODE, &error);
+        if (! error) {
+                _gs_prefs_set_mode (prefs, string);
+        } else {
+                key_error_and_free (KEY_MODE, error);
         }
         g_free (string);
 
-        value = gconf_client_get_int (prefs->priv->gconf_client, KEY_LOGOUT_DELAY, NULL);
-        if (value < 0)
-                value = 0;
-        prefs->logout_timeout = value * 60000;
+        list = gconf_client_get_list (prefs->priv->gconf_client,
+                                      KEY_THEMES, GCONF_VALUE_STRING, &error);
+        if (! error) {
+                _gs_prefs_set_themes (prefs, list);
+        } else {
+                key_error_and_free (KEY_THEMES, error);
+        }
+
+        /* DPMS options */
+
+        bvalue = gconf_client_get_bool (prefs->priv->gconf_client, KEY_DPMS_ENABLED, &error);
+        if (! error) {
+                _gs_prefs_set_dpms_enabled (prefs, bvalue);
+        } else {
+                key_error_and_free (KEY_DPMS_ENABLED, error);
+        }
+
+        value = gconf_client_get_int (prefs->priv->gconf_client, KEY_DPMS_STANDBY, &error);
+        if (! error) {
+                _gs_prefs_set_dpms_standby_timeout (prefs, value);
+        } else {
+                key_error_and_free (KEY_DPMS_STANDBY, error);
+        }
+
+        value = gconf_client_get_int (prefs->priv->gconf_client, KEY_DPMS_SUSPEND, &error);
+        if (! error) {
+                _gs_prefs_set_dpms_suspend_timeout (prefs, value);
+        } else {
+                key_error_and_free (KEY_DPMS_SUSPEND, error);
+        }
+
+        value = gconf_client_get_int (prefs->priv->gconf_client, KEY_DPMS_OFF, &error);
+        if (! error) {
+                _gs_prefs_set_dpms_off_timeout (prefs, value);
+        } else {
+                key_error_and_free (KEY_DPMS_OFF, error);
+        }
+
+        /* Logout options */
+
+        bvalue = gconf_client_get_bool (prefs->priv->gconf_client, KEY_LOGOUT_ENABLED, &error);
+        if (! error) {
+                _gs_prefs_set_logout_enabled (prefs, bvalue);
+        } else {
+                key_error_and_free (KEY_LOGOUT_ENABLED, error);
+        }
+
+        string = gconf_client_get_string (prefs->priv->gconf_client, KEY_LOGOUT_COMMAND, &error);
+        if (! error) {
+                _gs_prefs_set_logout_command (prefs, string);
+        } else {
+                key_error_and_free (KEY_LOGOUT_COMMAND, error);
+        }
+        g_free (string);
+
+        value = gconf_client_get_int (prefs->priv->gconf_client, KEY_LOGOUT_DELAY, &error);
+        if (! error) {
+                _gs_prefs_set_logout_timeout (prefs, value);
+        } else {
+                key_error_and_free (KEY_LOGOUT_DELAY, error);
+        }
 
         /* User switching options */
 
-        prefs->user_switch_enabled = gconf_client_get_bool (prefs->priv->gconf_client, KEY_USER_SWITCH_ENABLED, NULL);
+        bvalue = gconf_client_get_bool (prefs->priv->gconf_client, KEY_USER_SWITCH_ENABLED, &error);
+        if (! error) {
+                _gs_prefs_set_user_switch_enabled (prefs, bvalue);
+        } else {
+                key_error_and_free (KEY_USER_SWITCH_ENABLED, error);
+        }
+}
+
+static void
+invalid_type_warning (const char *type)
+{
+        g_warning ("Error retrieving configuration key '%s': Invalid type",
+                   type);
 }
 
 static void
@@ -237,17 +477,17 @@ key_changed_cb (GConfClient *client,
         value = gconf_entry_get_value (entry);
 
         if (strcmp (key, KEY_MODE) == 0) {
-                const char *str;
-                int         mode;
 
-                str = gconf_value_get_string (value);
+                if (value->type == GCONF_VALUE_STRING) {
+                        const char *str;
 
-                if (str && gconf_string_to_enum (mode_enum_map, str, &mode))
-                        prefs->mode = mode;
-                else
-                        prefs->mode = GS_MODE_BLANK_ONLY;
+                        str = gconf_value_get_string (value);
+                        _gs_prefs_set_mode (prefs, str);
 
-                changed = TRUE;
+                        changed = TRUE;
+                } else {
+                        invalid_type_warning (key);
+                }
 
         } else if (strcmp (key, KEY_THEMES) == 0) {
                 GSList *list = NULL;
@@ -262,115 +502,196 @@ key_changed_cb (GConfClient *client,
                 if (list
                     && gconf_value_get_list_type (value) == GCONF_VALUE_STRING) {
                         GSList *l;
+                        GSList *new_list;
 
                         changed = TRUE;
 
-                        if (prefs->themes) {
-                                g_slist_foreach (prefs->themes, (GFunc)g_free, NULL);
-                                g_slist_free (prefs->themes);
-                                prefs->themes = NULL;
-                        }
-
+                        new_list = NULL;
                         for (l = list; l; l = l->next) {
                                 char *s;
 
                                 s = gconf_value_to_string (l->data);
 
-                                prefs->themes = g_slist_append (prefs->themes, g_strdup (s));
+                                new_list = g_slist_prepend (new_list, g_strdup (s));
 
                                 g_free (s);
                         }
+
+                        new_list = g_slist_reverse (new_list);
+
+                        _gs_prefs_set_themes (prefs, new_list);
+
                 }
+
         } else if (strcmp (key, KEY_ACTIVATE_DELAY) == 0) {
-                int delay;
 
-                delay = gconf_value_get_int (value);
-                if (delay < 1)
-                        delay = 1;
-                prefs->timeout = delay * 60000;
-                changed = TRUE;
-        } else if (strcmp (key, KEY_LOCK_DELAY) == 0) {
-                int delay;
+                if (value->type == GCONF_VALUE_INT) {
+                        int delay;
 
-                delay = gconf_value_get_int (value);
-                prefs->lock_timeout = delay * 60000;
-                changed = TRUE;
-        } else if (strcmp (key, KEY_LOCK_ENABLED) == 0) {
-                gboolean enabled;
+                        delay = gconf_value_get_int (value);
+                        _gs_prefs_set_timeout (prefs, delay);
 
-                enabled = gconf_value_get_bool (value);
-                prefs->lock_enabled = enabled;
-                changed = TRUE;
-        } else if (strcmp (key, KEY_CYCLE_DELAY) == 0) {
-                int delay;
-
-                delay = gconf_value_get_int (value);
-                prefs->cycle = delay * 60000;
-                changed = TRUE;
-        } else if (strcmp (key, KEY_DPMS_ENABLED) == 0) {
-                gboolean enabled;
-
-                enabled = gconf_value_get_bool (value);
-                prefs->dpms_enabled = enabled;
-                changed = TRUE;
-        } else if (strcmp (key, KEY_DPMS_STANDBY) == 0) {
-                int timeout;
-
-                timeout = gconf_value_get_int (value);
-                if (timeout < 1)
-                        timeout = 1;
-                prefs->dpms_standby = timeout * 60000;
-                changed = TRUE;
-        } else if (strcmp (key, KEY_DPMS_SUSPEND) == 0) {
-                int timeout;
-
-                timeout = gconf_value_get_int (value);
-                if (timeout < 1)
-                        timeout = 1;
-                prefs->dpms_suspend = timeout * 60000;
-                changed = TRUE;
-        } else if (strcmp (key, KEY_DPMS_OFF) == 0) {
-                int timeout;
-
-                timeout = gconf_value_get_int (value);
-                if (timeout < 1)
-                        timeout = 1;
-                prefs->dpms_off = timeout * 60000;
-                changed = TRUE;
-        } else if (strcmp (key, KEY_LOGOUT_ENABLED) == 0) {
-                gboolean enabled;
-
-                enabled = gconf_value_get_bool (value);
-                prefs->logout_enabled = enabled;
-                changed = TRUE;
-        } else if (strcmp (key, KEY_LOGOUT_DELAY) == 0) {
-                int delay;
-
-                delay = gconf_value_get_int (value);
-                if (delay < 0)
-                        delay = 0;
-                prefs->logout_timeout = delay * 60000;
-                changed = TRUE;
-        } else if (strcmp (key, KEY_LOGOUT_COMMAND) == 0) {
-                const char *command;
-
-                command = gconf_value_get_string (value);
-
-                g_free (prefs->logout_command);
-
-                if (command) {
-                        prefs->logout_command = g_strdup (command);
+                        changed = TRUE;
                 } else {
-                        prefs->logout_command = NULL;
+                        invalid_type_warning (key);
                 }
 
-                changed = TRUE;
+        } else if (strcmp (key, KEY_LOCK_DELAY) == 0) {
+
+                if (value->type == GCONF_VALUE_INT) {
+                        int delay;
+
+                        delay = gconf_value_get_int (value);
+                        _gs_prefs_set_lock_timeout (prefs, delay);
+
+                        changed = TRUE;
+                } else {
+                        invalid_type_warning (key);
+                }
+
+        } else if (strcmp (key, KEY_IDLE_ACTIVATION_ENABLED) == 0) {
+
+                if (value->type == GCONF_VALUE_BOOL) {
+                        gboolean enabled;
+
+                        enabled = gconf_value_get_bool (value);
+                        _gs_prefs_set_idle_activation_enabled (prefs, enabled);
+
+                        changed = TRUE;
+                } else {
+                        invalid_type_warning (key);
+                }
+
+        } else if (strcmp (key, KEY_LOCK_ENABLED) == 0) {
+
+                if (value->type == GCONF_VALUE_BOOL) {
+                        gboolean enabled;
+
+                        enabled = gconf_value_get_bool (value);
+                        _gs_prefs_set_lock_enabled (prefs, enabled);
+
+                        changed = TRUE;
+                } else {
+                        invalid_type_warning (key);
+                }
+
+        } else if (strcmp (key, KEY_CYCLE_DELAY) == 0) {
+
+                if (value->type == GCONF_VALUE_INT) {
+                        int delay;
+
+                        delay = gconf_value_get_int (value);
+                        _gs_prefs_set_cycle_timeout (prefs, delay);
+
+                        changed = TRUE;
+                } else {
+                        invalid_type_warning (key);
+                }
+
+        } else if (strcmp (key, KEY_DPMS_ENABLED) == 0) {
+
+                if (value->type == GCONF_VALUE_BOOL) {
+                        gboolean enabled;
+
+                        enabled = gconf_value_get_bool (value);
+                        _gs_prefs_set_dpms_enabled (prefs, enabled);
+
+                        changed = TRUE;
+                } else {
+                        invalid_type_warning (key);
+                }
+
+        } else if (strcmp (key, KEY_DPMS_STANDBY) == 0) {
+
+                if (value->type == GCONF_VALUE_INT) {
+                        int timeout;
+
+                        timeout = gconf_value_get_int (value);
+                        _gs_prefs_set_dpms_standby_timeout (prefs, timeout);
+
+                        changed = TRUE;
+                } else {
+                        invalid_type_warning (key);
+                }
+
+        } else if (strcmp (key, KEY_DPMS_SUSPEND) == 0) {
+
+                if (value->type == GCONF_VALUE_INT) {
+                        int timeout;
+
+                        timeout = gconf_value_get_int (value);
+                        _gs_prefs_set_dpms_suspend_timeout (prefs, timeout);
+
+                        changed = TRUE;
+                } else {
+                        invalid_type_warning (key);
+                }
+
+        } else if (strcmp (key, KEY_DPMS_OFF) == 0) {
+
+                if (value->type == GCONF_VALUE_INT) {
+                        int timeout;
+
+                        timeout = gconf_value_get_int (value);
+                        _gs_prefs_set_dpms_off_timeout (prefs, timeout);
+
+                        changed = TRUE;
+                } else {
+                        invalid_type_warning (key);
+                }
+
+        } else if (strcmp (key, KEY_LOGOUT_ENABLED) == 0) {
+
+                if (value->type == GCONF_VALUE_BOOL) {
+                        gboolean enabled;
+
+                        enabled = gconf_value_get_bool (value);
+                        _gs_prefs_set_logout_enabled (prefs, enabled);
+
+                        changed = TRUE;
+                } else {
+                        invalid_type_warning (key);
+                }
+
+        } else if (strcmp (key, KEY_LOGOUT_DELAY) == 0) {
+
+                if (value->type == GCONF_VALUE_INT) {
+                        int delay;
+
+                        delay = gconf_value_get_int (value);
+                        _gs_prefs_set_logout_timeout (prefs, delay);
+
+                        changed = TRUE;
+                } else {
+                        invalid_type_warning (key);
+                }
+
+        } else if (strcmp (key, KEY_LOGOUT_COMMAND) == 0) {
+
+                if (value->type == GCONF_VALUE_STRING) {
+                        const char *command;
+
+                        command = gconf_value_get_string (value);
+                        _gs_prefs_set_logout_command (prefs, command);
+
+                        changed = TRUE;
+                } else {
+                        invalid_type_warning (key);
+                }
+
         } else if (strcmp (key, KEY_USER_SWITCH_ENABLED) == 0) {
-                gboolean enabled;
+
+                if (value->type == GCONF_VALUE_BOOL) {
+                        gboolean enabled;
+
+                        enabled = gconf_value_get_bool (value);
+                        _gs_prefs_set_user_switch_enabled (prefs, enabled);
+
+                        changed = TRUE;
+                } else {
+                        invalid_type_warning (key);
+                }
 
-                enabled = gconf_value_get_bool (value);
-                prefs->user_switch_enabled = enabled;
-                changed = TRUE;
         } else {
                 g_warning ("Config key not handled: %s", key);
         }
@@ -390,10 +711,11 @@ gs_prefs_init (GSPrefs *prefs)
         prefs->verbose                 = FALSE;
         prefs->debug                   = FALSE;
 
+        prefs->idle_activation_enabled = TRUE;
         prefs->lock_enabled            = TRUE;
         prefs->logout_enabled          = FALSE;
         prefs->user_switch_enabled     = FALSE;
-        prefs->dpms_enabled            = TRUE;
+        prefs->dpms_enabled            = FALSE;
         prefs->dpms_standby            = 7200000;
         prefs->dpms_suspend            = 7200000;
         prefs->dpms_off                = 14400000;
